package projects

import (
	db "ttime/internal/database"

	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/log"
	"github.com/golang-jwt/jwt/v5"
)

func ListAllUsersProject(c *fiber.Ctx) error {
	// Extract the project name from the request parameters or body
	projectName := c.Params("projectName")
	if projectName == "" {
		log.Info("No project name provided")
		return c.Status(400).SendString("No project name provided")
	}

	// Get the user token
	userToken := c.Locals("user").(*jwt.Token)
	claims := userToken.Claims.(jwt.MapClaims)
	username := claims["name"].(string)

	// Check if the user is a project manager for the specified project
	isManager, err := db.GetDb(c).IsProjectManager(username, projectName)
	if err != nil {
		log.Info("Error checking project manager status:", err)
		return c.Status(500).SendString(err.Error())
	}

	// If the user is not a project manager, check if the user is a site admin
	if !isManager {
		isAdmin, err := db.GetDb(c).IsSiteAdmin(username)
		if err != nil {
			log.Info("Error checking admin status:", err)
			return c.Status(500).SendString(err.Error())
		}
		if !isAdmin {
			log.Info("User is neither a project manager nor a site admin:", username)
			return c.Status(403).SendString("User is neither a project manager nor a site admin")
		}
	}

	// Get all users associated with the project from the database
	users, err := db.GetDb(c).GetAllUsersProject(projectName)
	if err != nil {
		log.Info("Error getting users for project:", err)
		return c.Status(500).SendString(err.Error())
	}

	log.Info("Returning users for project: ", projectName)

	// Return the list of users as JSON
	return c.JSON(users)
}
