package users

import (
	db "ttime/internal/database"

	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/log"
)

//	@Summary		ListsAllUsers
//	@Description	lists all users
//	@Tags			User
//	@Produce		json
//	@Security		JWT
//	@Success		200	{array}		string	"Successfully returned all users"
//	@Failure		401	{string}	string	"Unauthorized"
//	@Failure		500	{string}	string	"Internal server error"
//	@Router			/users/all [get]
//
// ListAllUsers returns a list of all users in the application database
func ListAllUsers(c *fiber.Ctx) error {
	// Get all users from the database
	users, err := db.GetDb(c).GetAllUsersApplication()
	if err != nil {
		log.Info("Error getting users from db:", err) // Debug print
		return c.Status(500).SendString(err.Error())
	}

	log.Info("Returning all users")
	// Return the list of users as JSON
	return c.JSON(users)
}
