import { api, APIResponse } from "../API/API";

/**
 * Removes a user from a project
 * @param {string} props.usernameToDelete - The username of user to remove
 * @param {string} props.projectName - Project to remove user from
 * @returns {void}
 * @example
 * const exampleUsername = "user";
 * const exampleProjectName "project";
 * RemoveUserFromProj({ userToRemove: exampleUsername, projectName: exampleProjectName });
 */

export default function RemoveUserFromProj(props: {
  userToRemove: string;
  projectName: string;
}): void {
  if (props.userToRemove === localStorage.getItem("username")) {
    alert("Cannot remove yourself");
    return;
  }
  api
    .removeUserFromProject(
      props.userToRemove,
      props.projectName,
      localStorage.getItem("accessToken") ?? "",
    )
    .then((response: APIResponse<void>) => {
      if (response.success) {
        alert(`${props.userToRemove} has been removed!`);
        location.reload();
      } else {
        alert(`${props.userToRemove} has not been removed due to an error`);
        console.error(response.message);
      }
    })
    .catch((error) => {
      alert(`${props.userToRemove} has not been removed due to an error`);
      console.error("An error occurred during deletion:", error);
    });
}
